@@ -48,5 +48,6 @@ var group__spa__names =
     [ "SPA_NAME_API_JACK_DEVICE", "group__spa__names.html#ga4cb20c60fee8e27040787ed9ec9e9a2e", null ],
     [ "SPA_NAME_API_JACK_SOURCE", "group__spa__names.html#ga11c2cbfdfb9e3c5c6f2567527be11f02", null ],
     [ "SPA_NAME_API_JACK_SINK", "group__spa__names.html#gac2d9defa0b11f106341260bc879a3d91", null ],
-    [ "SPA_NAME_API_VULKAN_COMPUTE_SOURCE", "group__spa__names.html#ga191088dbac1ee56122ceb215f16604d5", null ]
+    [ "SPA_NAME_API_VULKAN_COMPUTE_SOURCE", "group__spa__names.html#ga191088dbac1ee56122ceb215f16604d5", null ],
+    [ "SPA_NAME_API_VULKAN_COMPUTE_FILTER", "group__spa__names.html#ga4dbc7ed7f81507d09348aa39215f0edb", null ]
 ];
\ No newline at end of file
