@@ -25,7 +25,13 @@
 var NAVTREE =
 [
   [ "PipeWire", "index.html", [
-    [ "Overview", "page_overview.html", null ],
+    [ "Components", "index.html#autotoc_md0", null ],
+    [ "API Documentation", "index.html#autotoc_md1", null ],
+    [ "More Documentation", "index.html#autotoc_md2", null ],
+    [ "Resources", "index.html#autotoc_md3", null ],
+    [ "Overview", "page_overview.html", [
+      [ "Motivation", "page_overview.html#autotoc_md4", null ]
+    ] ],
     [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
     [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
     [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
@@ -57,27 +63,27 @@ var NAVTREEINDEX =
 [
 "annotated.html",
 "globals_defs_p.html",
-"globals_l.html",
-"group__pw__core.html",
-"group__pw__impl__metadata.html#ga400e2176366436ac8752c563400a8eda",
-"group__pw__log.html#ga073d2e07bc95bf80bb43e9d863bd2c8e",
-"group__pw__profiler.html#ga2270ff65dd05ec8d44b575d345b34ef7",
-"group__pw__session__manager.html#gab48a226b48e006093ea7849eada7a806",
-"group__spa__ansi.html#gad9ac3e26ccd0b443d1dcfcbbb6222b3e",
-"group__spa__device.html#gae5c1deaf4987a5c43c1462e46f18b19b",
-"group__spa__log.html#gaac5c4e7126208e70c4f68e5c0354544a",
-"group__spa__node.html#gafda72bd4c75a0c9111ad4106a15d2b3e",
-"group__spa__param.html#gga09c0ecc808ca333e1dd8a994b8809586a00dbc0b5d88eb993c91cdc08e92cdf50",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81afec5c9d4cb1dc263bc4a05291230422c",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea06d203d1c216b0d496cd008447828c14",
-"group__spa__pod.html#ga85016b1c73cf76d8c4789a6f539ac4ec",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a14f9bce34113fee61a81ccaea5b6677b",
-"page_pulseaudio.html#autotoc_md153",
-"structpw__endpoint__link__info.html#aea87c1744850124ef9bc31d92af578f1",
-"structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1",
-"structspa__command.html#abf1578cf1ed69aac1d0473684f804d4e",
-"structspa__loop__control.html#a392f811fbacb15de863fc0265031050f",
-"structspa__result__node__params.html#a9216b607f0684ca0fb5fe0a94c981dc9"
+"globals_k.html",
+"group__pw__context.html#gad466760a74623341ac33d267581ddf39",
+"group__pw__impl__link.html#ga67ddececedcfc23e682f0b860fcde648",
+"group__pw__link.html#gab53c62332a757ed234d5eb91a54a23ac",
+"group__pw__port.html#gac8fe785592185f71666d2d03903cc367",
+"group__pw__session__manager.html#gaa50cf4a5a59e55e6a003e21cc6376996",
+"group__spa__ansi.html#ga9691e3321fd9a291860a04b0d219d52f",
+"group__spa__device.html#gac59665317b0bc49197df89771abf6499",
+"group__spa__log.html#ga2cb43866ec2798103989dcafd611f28f",
+"group__spa__node.html#gae06e2ee893ca6c894411795b564161c6",
+"group__spa__param.html#gae3beebbcde434be3e21cbdb46edb92fc",
+"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81a830f30b6852ec554b690e5a8323a14b2",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaaf34c622412de4a1ec7637231f2eb560b",
+"group__spa__pod.html#ga7820560083401bab79329a6b3b138c7d",
+"group__spa__types.html#ga690dba641d1bb8f54c7b0ca7478e53cf",
+"page_midi.html#autotoc_md28",
+"structpw__client__session__methods.html#a54ba399f450c8ee5b85cfba7ad4b352a",
+"structpw__impl__port__events.html#a73104e5c2b8f887977945a597fa6b1ee",
+"structpw__stream__events.html#aab4b9831ef563920b401b1f9daf93042",
+"structspa__io__buffers.html",
+"structspa__pod__choice__body.html#a24335975777563cb1c8be5df46ed8aca"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
